@@ -1,17 +1,13 @@
 package Mus;
 
 use 5.008_005;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use strictures 2;
 use Import::Into;
 
-use Mu ();
-use MooX::StrictConstructor ();
-
 sub import {
-    my $caller = caller;
-    $_->import::into( $caller ) for qw/ Mu MooX::StrictConstructor /;
+    $_->import::into( 1 ) for qw/ Mu MooX::StrictConstructor /;
 }
 
 1;
@@ -23,6 +19,10 @@ __END__
 
 Mus - Mu but with slightly more typing and strict constructors
 
+=head1 STATUS
+
+=for html <a href="https://travis-ci.org/srchulo/Mus"><img src="https://travis-ci.org/srchulo/Mus.svg?branch=master"></a> <a href='https://coveralls.io/github/srchulo/Mus'><img src='https://coveralls.io/repos/github/srchulo/Mus/badge.svg' alt='Coverage Status' /></a>
+
 =head1 SYNOPSIS
 
   package Foo;
@@ -33,7 +33,7 @@ Mus - Mu but with slightly more typing and strict constructors
   rwp "hrwp";
   rw "hrw";
 
-  my $foo = Foo->new(i_don_exist => 5, hro => "exists", hrwp => "exists", hrw => "exists");
+  my $foo = Foo->new(i_dont_exist => 5, hro => "exists", hrwp => "exists", hrw => "exists");
 
   # Found unknown attribute(s) passed to the constructor: i_dont_exist at (eval 30) line 52.
   #     Foo::new("Foo", "i_dont_exist", 5, "hro", "exists", "hrwp", "exists", "hrw", ...) called at Foo.pl line 9
